import numpy as np
import pandas as pd

class DataHelper:
    def __init__(self):
        pass

    def normalize(self, df):
        mean = df.mean()
        std = df.std()

        return (df - mean) / std, mean, std

    def normalize_using(self, df, mean, std):
        return (df - mean) / std

    def create_sequences(self, values, window_size, y = None):
        output = []
        results = []
        for i in range(len(values) - window_size):
            output.append(values[i : (i + window_size)])
            if y is not None:
                results.append(y[i + window_size - 1])

        if y is not None:
            return np.stack(output), np.array(results)
        else:
            return np.stack(output)

    def fit_scaler_on_3D_array(self, array, scaler):
        scaler.fit(array[:,0,:]) # for each time series we take first timestep that we will fit scaler on
        return scaler

    def rescale_3D_array(self, array, scaler):
        for i in range(array.shape[0]):
            array[i] = scaler.transform(array[i])

    def get_anomalous_indices(self, is_window_anomaly, window_size, anomaly_windows_threshold):
        anomalous_indices = []
        for index in range(window_size - 1, len(is_window_anomaly)):
            if np.sum(is_window_anomaly[index - window_size + 1 : index+1]) >= anomaly_windows_threshold:
                anomalous_indices.append(index)

        return anomalous_indices
